==> mansiki0.11_20091124.zip: Mansiki-SOW-MakeMangaPaper.scm <==
; GIMP Script-Fu Mansiki Libs

(define ( Mansiki-SOW-MakeMangaPaper ) 
	(let* (
			(settingHash ( MSK-newHash ))
			(argsValueList 1)
			(argsTypeList '() )
			(argsTextList '())
			(argsOpionsList '())
			(argsCommentList '())
			(argsNameList '())
		)
		
		(set! argsTypeList (MSK-push argsTypeList "SF-DIRNAME"))
		(set! argsTextList (MSK-push argsTextList "保存先フォルダ"))
		(set! argsValueList (MSK-push argsValueList "mansiki"))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "保存先フォルダ"))
		(set! argsNameList (MSK-push argsNameList "dir4Title"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-STRING"))
		(set! argsTextList (MSK-push argsTextList "漫画タイトル"))
		(set! argsValueList (MSK-push argsValueList "manga_"))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "漫画タイトル"))
		(set! argsNameList (MSK-push argsNameList "title"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-STRING"))
		(set! argsTextList (MSK-push argsTextList "ファイル接頭文字（英数のみ推奨）"))
		(set! argsValueList (MSK-push argsValueList "_manga"))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "ファイル接頭文字（英数のみ推奨）"))
		(set! argsNameList (MSK-push argsNameList "filePrefix"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "総ページ数"))
		(set! argsValueList (MSK-push argsValueList 12))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "総ページ数"))
		(set! argsNameList (MSK-push argsNameList "pageNum"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "メインページ開始"))
		(set! argsValueList (MSK-push argsValueList 3))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "メインページ開始"))
		(set! argsNameList (MSK-push argsNameList "pageNumMainStart"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "メインページ最終"))
		(set! argsValueList (MSK-push argsValueList 10))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "メインページ最終"))
		(set! argsNameList (MSK-push argsNameList "pageNumMainEnd"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-OPTION"))
		(set! argsTextList (MSK-push argsTextList "原稿用紙サイズ"))
		(set! argsValueList (MSK-push argsValueList 0))
		(set! argsOpionsList (MSK-push argsOpionsList "B5_182x257 A4_210x297 B4_257x364"))
		(set! argsCommentList (MSK-push argsCommentList "B5_182x257 A4_210x297 B4_257x364  B5_182x257 A4_210x297 B4_257x364"));過去分とスタティック分
		(set! argsNameList (MSK-push argsNameList "paperSize"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "最終出力予定DPI"))
		(set! argsValueList (MSK-push argsValueList 600))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "最終DPI"))
		(set! argsNameList (MSK-push argsNameList "targetDPI"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "モニタ横解像度"))
		(set! argsValueList (MSK-push argsValueList 2560))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "モニタ横解像度"))
		(set! argsNameList (MSK-push argsNameList "monitorSizeX"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "モニタ縦解像度"))
		(set! argsValueList (MSK-push argsValueList 1600))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "モニタ縦解像度"))
		(set! argsNameList (MSK-push argsNameList "monitorSizeY"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-OPTION"))
		(set! argsTextList (MSK-push argsTextList "最適化レベル"))
		(set! argsValueList (MSK-push argsValueList 0))
		(set! argsOpionsList (MSK-push argsOpionsList "なし 内枠（用紙全体） 内枠（用紙カット）"))
		(set! argsCommentList (MSK-push argsCommentList "なし 内枠（用紙全体） 内枠（用紙カット）  なし 内枠（用紙全体） 内枠（用紙カット）"))
		(set! argsNameList (MSK-push argsNameList "optimazingLevel2MonitorSize"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-OPTION"))
		(set! argsTextList (MSK-push argsTextList "最適化時倍率"))
		(set! argsValueList (MSK-push argsValueList 0))
		(set! argsOpionsList (MSK-push argsOpionsList "x100% x50% x200% x400% x800%"))
		(set! argsCommentList (MSK-push argsCommentList "x100% x50% x200% x400% x800%  x100% x50% x200% x400% x800%"))
		(set! argsNameList (MSK-push argsNameList "severaltimesAs"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-OPTION"))
		(set! argsTextList (MSK-push argsTextList "ページ始まり"))
		(set! argsValueList (MSK-push argsValueList 0))
		(set! argsOpionsList (MSK-push argsOpionsList "左始まり 右始まり"))
		(set! argsCommentList (MSK-push argsCommentList "左始まり 右始まり  左始まり 右始まり"))
		(set! argsNameList (MSK-push argsNameList "startSide"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-OPTION"))
		(set! argsTextList (MSK-push argsTextList "ページ送り"))
		(set! argsValueList (MSK-push argsValueList 0))
		(set! argsOpionsList (MSK-push argsOpionsList "右→左_縦書き 左→右_横書き"))
		(set! argsCommentList (MSK-push argsCommentList "右→左_縦書き 左→右_横書き  右→左_縦書き 左→右_横書き"))
		(set! argsNameList (MSK-push argsNameList "pageFlowDirection"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-STRING"))
		(set! argsTextList (MSK-push argsTextList "著作者"))
		(set! argsValueList (MSK-push argsValueList "I am Me!"))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "著作者"))
		(set! argsNameList (MSK-push argsNameList "author"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-STRING"))
		(set! argsTextList (MSK-push argsTextList "再配布ライセンス"))
		(set! argsValueList (MSK-push argsValueList "CC-BY-SA"))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "再配布ライセンス"))
		(set! argsNameList (MSK-push argsNameList "license"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-STRING"))
		(set! argsTextList (MSK-push argsTextList "最終読み込み時間(編集しないで)"))
		(set! argsValueList (MSK-push argsValueList ( MSK-getNowDateTime ) ))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList ( MSK-getNowDateTime ) ))
		(set! argsNameList (MSK-push argsNameList "lastloadtime"))
		
		
		(set! settingHash ( MSK-addElement2Hash settingHash "name" "Mansiki-MakeMangaPaperWithSOW") )
		(set! settingHash ( MSK-addElement2Hash settingHash "ScriptPath" "<Toolbox>/Xtns/Mansiki") )
		(set! settingHash ( MSK-addElement2Hash settingHash "describe" "Mansiki-原稿用紙作成") )
		(set! settingHash ( MSK-addElement2Hash settingHash "nameFirst" "Mansiki") )
		(set! settingHash ( MSK-addElement2Hash settingHash "nameLast" "copyright") )
		(set! settingHash ( MSK-addElement2Hash settingHash "bornDate" "2008/10/07") )
		(set! settingHash ( MSK-addElement2Hash settingHash "licens" "GPLv3") )
		(set! settingHash ( MSK-addElement2Hash settingHash "callMethod" "MSK-MakeScriptFileAndMakeMangaPaper ") )
	
		( MSK-rewriteTheFile settingHash argsValueList argsTypeList argsTextList argsOpionsList argsCommentList argsNameList ) 

	)
)
;--------------------------------------------------
(script-fu-register "Mansiki-SOW-MakeMangaPaper"
		    "Mansiki-原稿用紙作成-リセット"
		    "Mansiki"
		    "name"
		    "Rongfu"
		    "2008/10/28"
		    "GPL"
	) 

(script-fu-menu-register "Mansiki-SOW-MakeMangaPaper"
		    "<Toolbox>/Xtns/Mansiki-test")

==> mansiki0.12_20100221.zip: Mansiki-SOW-MakeMangaPaper.scm <==

; GIMP Script-Fu Mansiki Libs

(define ( Mansiki-SOW-MakeMangaPaper ) 
	(let* (
			(settingHash ( MSK-newHash ))
			(argsValueList 1)
			(argsTypeList '() )
			(argsTextList '())
			(argsOpionsList '())
			(argsCommentList '())
			(argsNameList '())
		)
		
		(set! argsTypeList (MSK-push argsTypeList "SF-DIRNAME"))
		(set! argsTextList (MSK-push argsTextList "保存先フォルダ"))
		(set! argsValueList (MSK-push argsValueList "mansiki"))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "保存先フォルダ"))
		(set! argsNameList (MSK-push argsNameList "dir4Title"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-STRING"))
		(set! argsTextList (MSK-push argsTextList "漫画タイトル"))
		(set! argsValueList (MSK-push argsValueList "manga_"))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "漫画タイトル"))
		(set! argsNameList (MSK-push argsNameList "title"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-STRING"))
		(set! argsTextList (MSK-push argsTextList "ファイル接頭文字（英数のみ推奨）"))
		(set! argsValueList (MSK-push argsValueList "_manga"))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "ファイル接頭文字（英数のみ推奨）"))
		(set! argsNameList (MSK-push argsNameList "filePrefix"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "総ページ数"))
		(set! argsValueList (MSK-push argsValueList 12))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "総ページ数"))
		(set! argsNameList (MSK-push argsNameList "pageNum"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "メインページ開始"))
		(set! argsValueList (MSK-push argsValueList 3))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "メインページ開始"))
		(set! argsNameList (MSK-push argsNameList "pageNumMainStart"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "メインページ最終"))
		(set! argsValueList (MSK-push argsValueList 10))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "メインページ最終"))
		(set! argsNameList (MSK-push argsNameList "pageNumMainEnd"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-OPTION"))
		(set! argsTextList (MSK-push argsTextList "原稿用紙サイズ"))
		(set! argsValueList (MSK-push argsValueList 0))
		(set! argsOpionsList (MSK-push argsOpionsList "B5P_177x250 B5_182x257 A4_210x297 B4_257x364"))
		(set! argsCommentList (MSK-push argsCommentList "B5P_177x250 B5_182x257 A4_210x297 B4_257x364  B5P_177x250 B5_182x257 A4_210x297 B4_257x364"));過去分とスタティック分
		(set! argsNameList (MSK-push argsNameList "paperSize"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "最終出力予定DPI"))
		(set! argsValueList (MSK-push argsValueList 600))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "最終DPI"))
		(set! argsNameList (MSK-push argsNameList "targetDPI"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "モニタ横解像度"))
		(set! argsValueList (MSK-push argsValueList 2560))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "モニタ横解像度"))
		(set! argsNameList (MSK-push argsNameList "monitorSizeX"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-VALUE"))
		(set! argsTextList (MSK-push argsTextList "モニタ縦解像度"))
		(set! argsValueList (MSK-push argsValueList 1600))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "モニタ縦解像度"))
		(set! argsNameList (MSK-push argsNameList "monitorSizeY"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-OPTION"))
		(set! argsTextList (MSK-push argsTextList "最適化レベル"))
		(set! argsValueList (MSK-push argsValueList 0))
		(set! argsOpionsList (MSK-push argsOpionsList "なし 内枠（用紙全体） 内枠（用紙カット）"))
		(set! argsCommentList (MSK-push argsCommentList "なし 内枠（用紙全体） 内枠（用紙カット）  なし 内枠（用紙全体） 内枠（用紙カット）"))
		(set! argsNameList (MSK-push argsNameList "optimazingLevel2MonitorSize"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-OPTION"))
		(set! argsTextList (MSK-push argsTextList "最適化時倍率"))
		(set! argsValueList (MSK-push argsValueList 0))
		(set! argsOpionsList (MSK-push argsOpionsList "x100% x50% x200% x400% x800%"))
		(set! argsCommentList (MSK-push argsCommentList "x100% x50% x200% x400% x800%  x100% x50% x200% x400% x800%"))
		(set! argsNameList (MSK-push argsNameList "severaltimesAs"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-OPTION"))
		(set! argsTextList (MSK-push argsTextList "ページ始まり"))
		(set! argsValueList (MSK-push argsValueList 0))
		(set! argsOpionsList (MSK-push argsOpionsList "左始まり 右始まり"))
		(set! argsCommentList (MSK-push argsCommentList "左始まり 右始まり  左始まり 右始まり"))
		(set! argsNameList (MSK-push argsNameList "startSide"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-OPTION"))
		(set! argsTextList (MSK-push argsTextList "ページ送り"))
		(set! argsValueList (MSK-push argsValueList 0))
		(set! argsOpionsList (MSK-push argsOpionsList "右→左_縦書き 左→右_横書き"))
		(set! argsCommentList (MSK-push argsCommentList "右→左_縦書き 左→右_横書き  右→左_縦書き 左→右_横書き"))
		(set! argsNameList (MSK-push argsNameList "pageFlowDirection"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-STRING"))
		(set! argsTextList (MSK-push argsTextList "著作者"))
		(set! argsValueList (MSK-push argsValueList "I am Me!"))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "著作者"))
		(set! argsNameList (MSK-push argsNameList "author"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-STRING"))
		(set! argsTextList (MSK-push argsTextList "再配布ライセンス"))
		(set! argsValueList (MSK-push argsValueList "CC-BY-SA"))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList "再配布ライセンス"))
		(set! argsNameList (MSK-push argsNameList "license"))
		
		(set! argsTypeList (MSK-push argsTypeList "SF-STRING"))
		(set! argsTextList (MSK-push argsTextList "最終読み込み時間(編集しないで)"))
		(set! argsValueList (MSK-push argsValueList ( MSK-getNowDateTime ) ))
		(set! argsOpionsList (MSK-push argsOpionsList "options"))
		(set! argsCommentList (MSK-push argsCommentList ( MSK-getNowDateTime ) ))
		(set! argsNameList (MSK-push argsNameList "lastloadtime"))
		
		
		(set! settingHash ( MSK-addElement2Hash settingHash "name" "Mansiki-MakeMangaPaperWithSOW") )
		(set! settingHash ( MSK-addElement2Hash settingHash "ScriptPath" "<Toolbox>/Xtns/Mansiki") )
		(set! settingHash ( MSK-addElement2Hash settingHash "describe" "Mansiki-原稿用紙作成") )
		(set! settingHash ( MSK-addElement2Hash settingHash "nameFirst" "Mansiki") )
		(set! settingHash ( MSK-addElement2Hash settingHash "nameLast" "copyright") )
		(set! settingHash ( MSK-addElement2Hash settingHash "bornDate" "2008/10/07") )
		(set! settingHash ( MSK-addElement2Hash settingHash "licens" "GPLv3") )
		(set! settingHash ( MSK-addElement2Hash settingHash "callMethod" "MSK-MakeScriptFileAndMakeMangaPaper ") )
	
		( MSK-rewriteTheFile settingHash argsValueList argsTypeList argsTextList argsOpionsList argsCommentList argsNameList ) 

	)
)
;--------------------------------------------------
(script-fu-register "Mansiki-SOW-MakeMangaPaper"
		    "Mansiki-原稿用紙作成-リセット"
		    "Mansiki"
		    "name"
		    "Rongfu"
		    "2008/10/28"
		    "GPL"
	) 

(script-fu-menu-register "Mansiki-SOW-MakeMangaPaper"
		    "<Toolbox>/Xtns/Mansiki-test")
